cordova.define("simdoll-gameads.gameads", function(require, exports, module) {
var AD_ERROR_CODE_SUCCESS = 0;
var AD_ERROR_CODE_NOT_AVAILABLE_YET = -1;   // can try it layer
var AD_ERROR_CODE_QUOTA_LIMIT = -2;     // cannot play until quota reset
var AD_ERROR_CODE_ERROR = -3;   // generic error
var AD_ERROR_CODE_USER_CANCELED = -4;

module.exports = {
    //adsPluginName : ["vungle","unity"],
    //videoAdPlacementId : "rewardedVideo",
    getPluginNameList: function ()
    {
        var lst = [];
        for (var k in window.adsSupportedSDKs) {
            lst.push(k);
        }
        return lst;
    },
    //是否已经初始化数据
    is_init_data: false,
    initData: function(data)
    {
        console.log("gameads init");
        if(this.is_init_data)
            return;
        this.is_init_data = true;
        // 加载队列
        this.preloadQueue = [];
        // 是否在预加载中
        this.preloading = false;
        // 游戏内广告位查找表
        this.appPlacementIDLUT = data;
    },
    // 绑定广告加载成功监听函数
    bindVideoLoaded: function(cb)
    {
        this.video_ad_loaded_cb = cb;
    },
    /** 预加载激励视频广告
     * @param appPlacementID 游戏内广告位名字(uiName)
     */
    preloadVideo: function(appPlacementID)
    {
        console.log("preloadVideo1:" + appPlacementID);
        if(!this.is_init_data)
            return false;
        console.log("preloadVideo2:" + appPlacementID);
        // 按该位置的广告位顺序进行预加载
        var list = this.appPlacementIDLUT[appPlacementID];
        for(var data of list)
        {
            var ad_type = data.ad_type;
            if('rewardVideoAd' != ad_type) // 非激励视频广告位
                break;
            var pluginName = data.ad_channel_id;
            var plugin = window.adsSupportedSDKs[pluginName];
            if(!plugin)
                continue;
            // 判断SDK是否支持对应广告预加载
            if('function' !== typeof plugin.preloadVideo)
                continue;
            this.preloadQueue.push(data);
        }
        if(!this.preloading)
        {
            this._preloadNext();
        }
        return true;
    },
    _preloadNext: function()
    {
        if(this.preloadQueue.length > 0)
        {
            this.preloading = true;
            var data = this.preloadQueue.shift();
            this._preloadOne(data);
        }
        else
        {
            this.preloading = false;
        }
    },
    _preloadOne: function(data)
    {
        var pluginName = data.ad_channel_id;
        var plugin = window.adsSupportedSDKs[pluginName];
        var placement_id = data.ad_placement_id;
        console.log("sdk preloadVideo:" + placement_id);
        plugin.preloadVideo(placement_id, function(){
            this._onPreloadSuccess(data);
        }.bind(this), this._onPreloadFailed.bind(this));
    },
    _onPreloadSuccess: function(data)
    {
        console.log("video loaded succ:" + data.app_placement_id);
        if(this.video_ad_loaded_cb)
        {
            this.video_ad_loaded_cb(data);
        }
        this._preloadNext();
    },
    _onPreloadFailed: function(errCode)
    {
        //重新加载
        this._preloadNext();
    },
    showVideoAd: function (adsName, placementID, resCallback) {
        if (adsName == "vungle") {
            vungle.showRewardedVideoAd(placementID, function (error, success) {
                if (error) {
                    if("not cached" === error){
                        resCallback(AD_ERROR_CODE_NOT_AVAILABLE_YET, null);
                    }else{
                        var m = /View Completed = (true|false)/.exec(error);
                        if (m && m[1] == 'false') {
                            resCallback(AD_ERROR_CODE_USER_CANCELED, null);
                        } else {
                            resCallback(AD_ERROR_CODE_ERROR, null);
                        }
                    }
                } else {
                    resCallback(AD_ERROR_CODE_SUCCESS, success);
                }
            });
        } else if (adsName == "unity") {
            unityads2.ShowVideoAd(placementID, function callback(error, result) {
                if ("COMPLETED" == result) {
                    resCallback(AD_ERROR_CODE_SUCCESS, "dummy token from unity");
                } else if ("SKIPPED" == error) {
                    resCallback(AD_ERROR_CODE_USER_CANCELED, null);
                } else {
                    resCallback(AD_ERROR_CODE_ERROR, null);
                }
                /*

                                    if(error){
                                        console.log(error);
                                        resCallback(error, null);
                                        return;
                                    }
                                    console.log(result);
                                    try{
                                        var result = JSON.parse(result);
                                        if(result[0] == "rewardedVideo" && result[1] == "COMPLETED")
                                            resCallback(null, "success");
                                    }catch (e) {
                                        resCallback("error", null);
                                    }*/
            });
        }else{
            if(!window.adsSupportedSDKs[adsName]){
                resCallback("error:not find" + adsName, null);
                return;
            }
            window.adsSupportedSDKs[adsName].playAD(placementID,function(){  // success
                console.log("play video succ");
                resCallback(AD_ERROR_CODE_SUCCESS, "dummy token from " + adsName);
            },function(errCode, message){   // failed
                console.log("play video fail");
                resCallback(errCode, message);
            });
        }
    },
    /** 预加载插屏
     * @param adsName & adUnitId
     */
    preloadInterstitialAd: function(info)
    {
       if(!info || !info.adsName || !info.adUnitId || !window.adsSupportedSDKs[info.adsName] || !window.adsSupportedSDKs[info.adsName].preloadInterstitialAd) return;
       window.adsSupportedSDKs[info.adsName].preloadInterstitialAd(info);
    },
    /**
     * 更新开屏广告ID
     * info数据能找到对应广告SDK就更新新的开屏广告ID，否则清空开屏广告
     */
    updateSplashUnitID: function(info)
    {
        if(info && info.adsName && info.adUnitId && window.adsSupportedSDKs[info.adsName] && window.adsSupportedSDKs[info.adsName].updateSplashUnitID)
        {
            window.adsSupportedSDKs[info.adsName].updateSplashUnitID(info.adUnitId,info.interval);
        }
        else
        {
            for (var k in window.adsSupportedSDKs)
            {
                var adsSDK = window.adsSupportedSDKs[k];
                if(adsSDK.updateSplashUnitID)
                {
                    adsSDK.updateSplashUnitID('');
                    break;  // 原生存档数据是唯一的，只需要一个SDK执行清理就行了。
                }
            }
        }
    },
    splashAd:function(info){
       if(!info || !info.adsName || !info.adUnitId || !window.adsSupportedSDKs[info.adsName] || !window.adsSupportedSDKs[info.adsName].interstitialAd) return;
       window.adsSupportedSDKs[info.adsName].splashAd(info);
    },
    interstitialAd:function(info)
    {
       if(!info || !info.adsName || !info.adUnitId || !window.adsSupportedSDKs[info.adsName] || !window.adsSupportedSDKs[info.adsName].interstitialAd) return;
       window.adsSupportedSDKs[info.adsName].interstitialAd(info);
    },
    /***
    {
        adsName:"csj",
        adUnitId:"广告ID",
        width:0,
        height:0
    }
    ***/
    opendBannerAds : {},
    showBanner:function(info)
    {
       if(!info || !info.adsName || !info.adUnitId || !window.adsSupportedSDKs[info.adsName] || !window.adsSupportedSDKs[info.adsName].showBanner) return;
       this.opendBannerAds[info.adsName] = window.adsSupportedSDKs[info.adsName];
       window.adsSupportedSDKs[info.adsName].showBanner(info);
    },
    hideBanner:function()
    {
        if(!window.adsSupportedSDKs) return;
        for (var k in this.opendBannerAds) {
            this.opendBannerAds[k].hideBanner();
        }
    },
    getPlayAdsName: function (rsCallBack)
    {
        this.successAds = [];

        if (window.vungle) {
            vungle.isPlay(function (showRs) {
                this.successAds.push({
                    rs: showRs == "success",
                    name: "vungle"
                });
                if (this.successAds.length >= this.adsPluginName.length)
                    rsCallBack(this.successAds);
            }.bind(this));
        }


        unityads2.GetPlacementState(this.videoAdPlacementId, function (error, result) {
            if (result) {
                this.successAds.push({
                    rs: true,
                    name: "unity"
                });
            } else {
                this.successAds.push({
                    rs: false,
                    name: "unity"
                });
            }
            if (this.successAds.length >= this.adsPluginName.length)
                rsCallBack(this.successAds);
        }.bind(this));
    }
};
});
